#!/usr/bin/env python
# encoding: utf-8

from blueflask.flask_api import FlaskApp

from .v1 import api
from .v1 import __version__
from ..consts import ADDRESS
from ..consts import APIGW
from ..consts import LOGS
from ..consts import HOSTNAME
from ..consts import SERVICE_CODE

import requests

flask_app = FlaskApp(SERVICE_CODE)
flask_app.produce_handlers_and_documentation()

app = flask_app.app
app.config['LOGGER_NAME'] = 'fup-services-api'
app.config['TITLE'] = 'API FUP'
app.config['DESCRIPTION'] = "Gestion des politiques de bon usage"
app.config['SERVICE_CODE'] = SERVICE_CODE
app.config['VERSION'] = __version__
app.logger.handlers = LOGS.logger.handlers
app.register_blueprint(api)


requests.post(
    'https://{fqdn}/registry'.format(fqdn=APIGW),
    json={
        'service': 'fup',
        'address': ADDRESS,
        'service_code': SERVICE_CODE,
        'host': HOSTNAME,
        'status': 'up'
        }
    )

# EOF
